@@ -18,11 +18,11 @@ use strict;
 use warnings;
 use Exporter;
 use Carp;
-use XML::Writer;
 use IO::File;
+use Excel::Writer::XLSX::Package::XMLwriterSimple;
 
 our @ISA     = qw(Exporter);
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 ###############################################################################
@@ -47,20 +47,42 @@ sub new {
 #
 # _set_xml_writer()
 #
-# Set the XML::Writer for the object.
+# Set the XML writer class for the object. For speed we use the internal
+# Excel::Writer::XLSX::Package::XMLwriterSimple class but for XML error
+# and correctness checking we can use the CPAN module XML::Writer.
+#
+# In general use we use XMLwriterSimple but maintain compatibility with
+# XML::Writer for testing purposes. We can choose between the two using an
+# environmental variable:
+#
+#    export _EXCEL_WRITER_XLSX_USE_XML_WRITER=1
+#
+# For one off testing we can use the following:
+#
+#    _EXCEL_WRITER_XLSX_USE_XML_WRITER=1 perl example.pl
 #
 sub _set_xml_writer {
 
     my $self     = shift;
     my $filename = shift;
 
-    my $fh = new IO::File( $filename, 'w' );
+    my $fh = IO::File->new( $filename, 'w' );
     croak "Couldn't open file $filename for writing.\n" unless $fh;
 
     binmode $fh, ':utf8';
 
-    my $writer = new XML::Writer( OUTPUT => $fh );
-    croak "Couldn't create XML::Writer for $filename.\n" unless $writer;
+    my $writer;
+
+    if ( $ENV{_EXCEL_WRITER_XLSX_USE_XML_WRITER} ) {
+        require XML::Writer;
+        $writer = XML::Writer->new( OUTPUT => $fh );
+    }
+    else {
+        $writer = Excel::Writer::XLSX::Package::XMLwriterSimple->new( $fh );
+
+    }
+
+    croak "Couldn't create XML writer object for $filename.\n" unless $writer;
 
     $self->{_writer} = $writer;
 }
@@ -100,7 +122,7 @@ See the documentation for L<Excel::Writer::XLSX>.
 
 =head1 DESCRIPTION
 
-This module is used in conjunction with L<Excel::Writer::XLSX>. This module uses L<XML::Writer>.
+This module is used in conjunction with L<Excel::Writer::XLSX>.
 
 =head1 AUTHOR
 
@@ -108,7 +130,7 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMX, John McNamara.
+ MM-MMXI, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
 
